@@ -1,10 +1,12 @@
 import tensorflow as tf
-from SRGAN.networks import Generator
+from gan_recover_image.SRGAN.networks import Generator
 import os
 
+
 class SRGanSingletone:
     __instance__ = None
     GEN = None
+
     def __init__(self):
         if SRGanSingletone.__instance__ is None:
             SRGanSingletone.__instance__ = self
